==> haskell-cryptohash-conduit-0.1.1-74-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-G0nOmDdIl4P7y7wVAlgys7
key: cryptohash-conduit-0.1.1-G0nOmDdIl4P7y7wVAlgys7
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
abi: c27527dd06274e3271054d5e5c16847a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-conduit-0.1.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-G0nOmDdIl4P7y7wVAlgys7
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.16-LbHEhSYrKrIKl2iEItQ5UA
    cryptohash-0.11.9-EjTCuGWNnJgLPmpaJ7EYxG
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-conduit-0.1.1-85-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-5PUjYs2H1dV267VxV2CQ1a
key: cryptohash-conduit-0.1.1-5PUjYs2H1dV267VxV2CQ1a
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
abi: 0a96583a32bbfcba4e3d838ea7369df8
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-conduit-0.1.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-5PUjYs2H1dV267VxV2CQ1a
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.11-5u7YE5Ecuce5vjjIFEkula
    conduit-extra-1.1.16-64t3TdZCM2WFvJMJ9glban
    cryptohash-0.11.9-Euve7brGLaM2bzKmxTqm1a
    resourcet-1.1.9-5Fmv0DqXfJBCCiUazI0vW3 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
